import {Schema, ObjectId, model} from "mongoose";
import encrypt from "mongoose-encryption";

export interface IAccount {
    id: ObjectId,
    username: string,
    email: string,
    password: string,
    totpSecret?: string
}

const AccountSchema = new Schema<IAccount>({
    username: {
        type: String,
        required: true
    },
    email: {
        type: String,
        required: true,
    },
    password: {
        type: String,
        required: true
    },
    totpSecret: String
});

AccountSchema.plugin(encrypt, {
    encryptionKey: process.env.ENC_KEY,
    signingKey: process.env.SIG_KEY
});

export const Account = model<IAccount>("accounts", AccountSchema);