import {model, ObjectId, Schema, Types} from "mongoose";
import encrypt from "mongoose-encryption";

interface ISession {
    id: ObjectId,
    userId: ObjectId,
    token: string,
    userAgent: string
}

const SessionSchema = new Schema<ISession>({
    userId: {
        type: Types.ObjectId,
        required: true
    },
    token: {
        type: String,
        required: true
    },
    userAgent: String
});

SessionSchema.plugin(encrypt, {
    encryptionKey: process.env.ENC_KEY,
    signingKey: process.env.SIG_KEY
});

export const Session = model<ISession>("sessions", SessionSchema);